"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.video.v1.episode_pb2
import yandex.cloud.video.v1.episode_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class EpisodeServiceStub:
    """Episode management service."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeRequest,
        yandex.cloud.video.v1.episode_pb2.Episode,
    ]
    """Returns the specific channel."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesRequest,
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse,
    ]
    """List episodes for stream or line."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.CreateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create episode."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.UpdateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update episode."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.DeleteEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete episode."""

    PerformAction: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.PerformEpisodeActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the episode."""

    GetPlayerURL: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse,
    ]
    """Returns url to the player."""

    GetManifests: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse,
    ]
    """Returns manifest urls."""

class EpisodeServiceAsyncStub:
    """Episode management service."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeRequest,
        yandex.cloud.video.v1.episode_pb2.Episode,
    ]
    """Returns the specific channel."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesRequest,
        yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse,
    ]
    """List episodes for stream or line."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.CreateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Create episode."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.UpdateEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Update episode."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.DeleteEpisodeRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Delete episode."""

    PerformAction: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.PerformEpisodeActionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Perform an action on the episode."""

    GetPlayerURL: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse,
    ]
    """Returns url to the player."""

    GetManifests: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsRequest,
        yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse,
    ]
    """Returns manifest urls."""

class EpisodeServiceServicer(metaclass=abc.ABCMeta):
    """Episode management service."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.GetEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_pb2.Episode, collections.abc.Awaitable[yandex.cloud.video.v1.episode_pb2.Episode]]:
        """Returns the specific channel."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.ListEpisodesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.ListEpisodesResponse]]:
        """List episodes for stream or line."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.CreateEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Create episode."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.UpdateEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Update episode."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.DeleteEpisodeRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Delete episode."""

    @abc.abstractmethod
    def PerformAction(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.PerformEpisodeActionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Perform an action on the episode."""

    @abc.abstractmethod
    def GetPlayerURL(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.GetEpisodePlayerURLResponse]]:
        """Returns url to the player."""

    @abc.abstractmethod
    def GetManifests(
        self,
        request: yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse, collections.abc.Awaitable[yandex.cloud.video.v1.episode_service_pb2.GetEpisodeManifestsResponse]]:
        """Returns manifest urls."""

def add_EpisodeServiceServicer_to_server(servicer: EpisodeServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.containerregistry.v1.scan_policy_pb2
import yandex.cloud.containerregistry.v1.scan_policy_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ScanPolicyServiceStub:
    """A set of methods for managing scan policy resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.GetScanPolicyRequest,
        yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy,
    ]
    """Returns the specified scan policy."""

    GetByRegistry: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.GetScanPolicyByRegistryRequest,
        yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy,
    ]
    """Returns scan policy for the registry if any exists."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.CreateScanPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a scan policy for the specified registry."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.UpdateScanPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified scan policy."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.DeleteScanPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified scan policy."""

class ScanPolicyServiceAsyncStub:
    """A set of methods for managing scan policy resources."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.GetScanPolicyRequest,
        yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy,
    ]
    """Returns the specified scan policy."""

    GetByRegistry: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.GetScanPolicyByRegistryRequest,
        yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy,
    ]
    """Returns scan policy for the registry if any exists."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.CreateScanPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a scan policy for the specified registry."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.UpdateScanPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified scan policy."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.containerregistry.v1.scan_policy_service_pb2.DeleteScanPolicyRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified scan policy."""

class ScanPolicyServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing scan policy resources."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.containerregistry.v1.scan_policy_service_pb2.GetScanPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy]]:
        """Returns the specified scan policy."""

    @abc.abstractmethod
    def GetByRegistry(
        self,
        request: yandex.cloud.containerregistry.v1.scan_policy_service_pb2.GetScanPolicyByRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy, collections.abc.Awaitable[yandex.cloud.containerregistry.v1.scan_policy_pb2.ScanPolicy]]:
        """Returns scan policy for the registry if any exists."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.containerregistry.v1.scan_policy_service_pb2.CreateScanPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a scan policy for the specified registry."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.containerregistry.v1.scan_policy_service_pb2.UpdateScanPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified scan policy."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.containerregistry.v1.scan_policy_service_pb2.DeleteScanPolicyRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified scan policy."""

def add_ScanPolicyServiceServicer_to_server(servicer: ScanPolicyServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



import uuid
from threading import Event

import grpc
import pytest

import yandex.cloud.compute.v1.zone_service_pb2 as zone_service_pb2
import yandex.cloud.compute.v1.zone_service_pb2_grpc as zone_service_pb2_grpc
from tests.grpc_server_mock import DEFAULT_ZONE, default_channel, grpc_server
from yandexcloud import RetryInterceptor, backoff_linear_with_jitter, default_backoff


class _FailFirstAttempts:
    def __init__(self, fail_attempts, code=grpc.StatusCode.UNAVAILABLE):
        self.__fail_attempts = fail_attempts
        self.code = code

    def handler(self, context):
        if self.__fail_attempts > 0:
            self.__fail_attempts -= 1
            context.set_code(self.code)

        return DEFAULT_ZONE

    def reset(self, fail_attempts):
        self.__fail_attempts = fail_attempts


def test_five_retries():
    service = _FailFirstAttempts(5)
    server = grpc_server(service.handler)
    request = zone_service_pb2.GetZoneRequest(zone_id="id")

    with default_channel() as channel:
        for max_retry_count in range(4):
            interceptor = RetryInterceptor(max_retry_count=max_retry_count)
            ch = grpc.intercept_channel(channel, interceptor)
            client = zone_service_pb2_grpc.ZoneServiceStub(ch)

            with pytest.raises(grpc.RpcError) as e:
                client.Get(request)

            assert e.value.code() == grpc.StatusCode.UNAVAILABLE
            service.reset(5)

        interceptor = RetryInterceptor(max_retry_count=5)
        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)
        res = client.Get(request)

        assert res == DEFAULT_ZONE

    server.stop(0)


def test_five_retries_internal():
    service = _FailFirstAttempts(5, code=grpc.StatusCode.INTERNAL)
    server = grpc_server(service.handler)
    request = zone_service_pb2.GetZoneRequest(zone_id="id")
    retriable_codes = (
        grpc.StatusCode.UNAVAILABLE,
        grpc.StatusCode.RESOURCE_EXHAUSTED,
        grpc.StatusCode.INTERNAL,
    )

    with default_channel() as channel:
        for max_retry_count in range(4):
            interceptor = RetryInterceptor(max_retry_count=max_retry_count, retriable_codes=retriable_codes)
            ch = grpc.intercept_channel(channel, interceptor)
            client = zone_service_pb2_grpc.ZoneServiceStub(ch)

            with pytest.raises(grpc.RpcError) as e:
                client.Get(request)

            assert e.value.code() == grpc.StatusCode.INTERNAL
            service.reset(5)

        interceptor = RetryInterceptor(max_retry_count=5, retriable_codes=retriable_codes)
        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)
        res = client.Get(request)

        assert res == DEFAULT_ZONE

    server.stop(0)


class _RetriableCodes:
    def __init__(self, retriable_codes):
        self.__retriable_codes = retriable_codes
        self.__get_count = 0

    def handler(self, context):
        if self.__get_count < len(self.__retriable_codes):
            context.set_code(self.__retriable_codes[self.__get_count])

        self.__get_count += 1
        return DEFAULT_ZONE

    def reset_state(self):
        self.__get_count = 0


def test_retriable_codes():
    retriable_codes = [grpc.StatusCode.RESOURCE_EXHAUSTED, grpc.StatusCode.UNAVAILABLE, grpc.StatusCode.DATA_LOSS]

    service = _RetriableCodes(retriable_codes)
    server = grpc_server(service.handler)

    with default_channel() as channel:
        for retry_qty in range(len(retriable_codes)):
            interceptor = RetryInterceptor(max_retry_count=retry_qty, retriable_codes=retriable_codes)
            ch = grpc.intercept_channel(channel, interceptor)
            client = zone_service_pb2_grpc.ZoneServiceStub(ch)

            with pytest.raises(grpc.RpcError) as e:
                client.Get(zone_service_pb2.GetZoneRequest(zone_id="id"))

            assert e.value.code() == retriable_codes[retry_qty]
            service.reset_state()

        interceptor = RetryInterceptor(max_retry_count=len(retriable_codes), retriable_codes=retriable_codes)
        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)
        assert client.Get(zone_service_pb2.GetZoneRequest(zone_id="id")) == DEFAULT_ZONE

    server.stop(0)


class _AlwaysUnavailable:
    def __init__(self):
        self.__get_count = 0
        self.__t_checker = None
        self.__error = False

    @property
    def error(self):
        return self.__error

    def handler(self, context):
        if self.__t_checker and not self.__t_checker():
            self.__error = True

        self.__get_count += 1

        if self.__get_count == 100:
            pass

        context.set_code(grpc.StatusCode.UNAVAILABLE)
        return DEFAULT_ZONE


@pytest.mark.parametrize("backoff", [None, default_backoff(), backoff_linear_with_jitter(0.05, 0.1)])
def test_infinite_retries_deadline_and_backoff(backoff):
    service = _AlwaysUnavailable()
    server = grpc_server(service.handler)

    with default_channel() as channel:
        interceptor = RetryInterceptor(
            max_retry_count=-1,
            retriable_codes=[grpc.StatusCode.UNAVAILABLE],
            add_retry_count_to_header=True,
            back_off_func=backoff,
        )

        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)

        with pytest.raises(grpc.RpcError) as e:
            client.Get(zone_service_pb2.GetZoneRequest(zone_id="id"), timeout=5)

        assert e.value.code() == grpc.StatusCode.DEADLINE_EXCEEDED

    server.stop(0)


class _NeverReturnsInTime:
    def __init__(self, shutdown):
        self.__shutdown = shutdown

    def handler(self, context):
        time_remaining = context.time_remaining()

        # using hack here, since deadline is never None. 31557600 ~= one year in seconds
        if time_remaining < 31557600.0:
            self.__shutdown.wait()

        context.set_code(grpc.StatusCode.UNAVAILABLE)
        return DEFAULT_ZONE


def test_per_call_timeout():
    shutdown = Event()
    service = _NeverReturnsInTime(shutdown)
    server = grpc_server(service.handler)

    with default_channel() as channel:
        interceptor = RetryInterceptor(
            max_retry_count=10,
            retriable_codes=[grpc.StatusCode.UNAVAILABLE],
            per_call_timeout=1,
            add_retry_count_to_header=True,
        )

        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)

        with pytest.raises(grpc.RpcError) as e:
            client.Get(zone_service_pb2.GetZoneRequest(zone_id="id"))

        assert e.value.code() == grpc.StatusCode.DEADLINE_EXCEEDED

    shutdown.set()
    server.stop(1)


class _HeaderTokenAndRetryCount:
    def __init__(self):
        self.__query_count = 0
        self.__token = None
        self.__token_error = False
        self.__header_error = False

    @property
    def error(self):
        return self.__header_error or self.__token_error

    def handler(self, context):
        metadata = context.invocation_metadata()

        if metadata is not None:
            token = [v[1] for v in metadata if v[0] == "idempotency-key"]

            if len(token) != 1:
                self.__token_error = True
            else:
                # store token on first call, on consequent calls, check that token didn't change
                if self.__query_count == 0:
                    self.__token = token[0]
                else:
                    if self.__token != token[0]:
                        self.__token_error = True

            if self.__query_count > 0:
                retry_meta = [v[1] for v in metadata if v[0] == "x-retry-attempt"]

                if len(retry_meta) != 1 or retry_meta[0] != str(self.__query_count):
                    self.__header_error = True
        else:
            self.__token_error = True
            self.__header_error = True

        self.__query_count += 1

        context.set_code(grpc.StatusCode.UNAVAILABLE)
        return DEFAULT_ZONE


def test_header_token_and_retry_count():
    service = _HeaderTokenAndRetryCount()
    server = grpc_server(service.handler)

    with default_channel() as channel:
        interceptor = RetryInterceptor(
            max_retry_count=100, retriable_codes=[grpc.StatusCode.UNAVAILABLE], add_retry_count_to_header=True
        )
        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)

        with pytest.raises(grpc.RpcError) as e:
            client.Get(zone_service_pb2.GetZoneRequest(zone_id="id"))

        assert e.value.code() == grpc.StatusCode.UNAVAILABLE

    assert not service.error
    server.stop(0)


class _TokenUnchanged:
    def __init__(self, token):
        self.__token = token
        self.__token_changed = False

    @property
    def token_changed(self):
        return self.__token_changed

    def handler(self, context):
        metadata = context.invocation_metadata()

        if metadata is not None:
            token = [v[1] for v in metadata if v[0] == "idempotency-key"]

            if len(token) != 1 or token[0] != self.__token:
                self.__token_changed = True
        else:
            self.__token_changed = True

        context.set_code(grpc.StatusCode.UNAVAILABLE)
        return DEFAULT_ZONE


def test_idempotency_token_not_changed():
    token = str(uuid.uuid4())
    service = _TokenUnchanged(token)
    server = grpc_server(service.handler)

    with default_channel() as channel:
        interceptor = RetryInterceptor(
            max_retry_count=100, retriable_codes=[grpc.StatusCode.UNAVAILABLE], add_retry_count_to_header=True
        )
        ch = grpc.intercept_channel(channel, interceptor)
        client = zone_service_pb2_grpc.ZoneServiceStub(ch)

        with pytest.raises(grpc.RpcError) as e:
            client.Get(zone_service_pb2.GetZoneRequest(zone_id="id"), metadata=[("idempotency-key", token)])

        assert e.value.code() == grpc.StatusCode.UNAVAILABLE

    assert not service.token_changed
    server.stop(0)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/dataproc/v1/resource_preset_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.dataproc.v1 import resource_preset_pb2 as yandex_dot_cloud_dot_dataproc_dot_v1_dot_resource__preset__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/dataproc/v1/resource_preset_service.proto\x12\x18yandex.cloud.dataproc.v1\x1a\x1cgoogle/api/annotations.proto\x1a.yandex/cloud/dataproc/v1/resource_preset.proto\x1a\x1dyandex/cloud/validation.proto\"<\n\x18GetResourcePresetRequest\x12 \n\x12resource_preset_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"Z\n\x1aListResourcePresetsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\"\x85\x01\n\x1bListResourcePresetsResponse\x12\x42\n\x10resource_presets\x18\x01 \x03(\x0b\x32(.yandex.cloud.dataproc.v1.ResourcePreset\x12\"\n\x0fnext_page_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=1002\xd4\x02\n\x15ResourcePresetService\x12\x9e\x01\n\x03Get\x12\x32.yandex.cloud.dataproc.v1.GetResourcePresetRequest\x1a(.yandex.cloud.dataproc.v1.ResourcePreset\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/dataproc/v1/resourcePresets/{resource_preset_id}\x12\x99\x01\n\x04List\x12\x34.yandex.cloud.dataproc.v1.ListResourcePresetsRequest\x1a\x35.yandex.cloud.dataproc.v1.ListResourcePresetsResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/dataproc/v1/resourcePresetsBe\n\x1cyandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataprocb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.dataproc.v1.resource_preset_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\034yandex.cloud.api.dataproc.v1ZEgithub.com/yandex-cloud/go-genproto/yandex/cloud/dataproc/v1;dataproc'
  _GETRESOURCEPRESETREQUEST.fields_by_name['resource_preset_id']._options = None
  _GETRESOURCEPRESETREQUEST.fields_by_name['resource_preset_id']._serialized_options = b'\350\3071\001'
  _LISTRESOURCEPRESETSREQUEST.fields_by_name['page_size']._options = None
  _LISTRESOURCEPRESETSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTRESOURCEPRESETSREQUEST.fields_by_name['page_token']._options = None
  _LISTRESOURCEPRESETSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTRESOURCEPRESETSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTRESOURCEPRESETSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\212\3101\005<=100'
  _RESOURCEPRESETSERVICE.methods_by_name['Get']._options = None
  _RESOURCEPRESETSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0023\0221/dataproc/v1/resourcePresets/{resource_preset_id}'
  _RESOURCEPRESETSERVICE.methods_by_name['List']._options = None
  _RESOURCEPRESETSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\036\022\034/dataproc/v1/resourcePresets'
  _globals['_GETRESOURCEPRESETREQUEST']._serialized_start=193
  _globals['_GETRESOURCEPRESETREQUEST']._serialized_end=253
  _globals['_LISTRESOURCEPRESETSREQUEST']._serialized_start=255
  _globals['_LISTRESOURCEPRESETSREQUEST']._serialized_end=345
  _globals['_LISTRESOURCEPRESETSRESPONSE']._serialized_start=348
  _globals['_LISTRESOURCEPRESETSRESPONSE']._serialized_end=481
  _globals['_RESOURCEPRESETSERVICE']._serialized_start=484
  _globals['_RESOURCEPRESETSERVICE']._serialized_end=824
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LogStatement:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogStatementEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogStatement.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    LOG_STATEMENT_UNSPECIFIED: _LogStatement.ValueType  # 0
    NONE: _LogStatement.ValueType  # 1
    """None statements are logged."""
    DDL: _LogStatement.ValueType  # 2
    """Logs all data definition commands like `CREATE`, `ALTER`, and `DROP`. Default value."""
    MOD: _LogStatement.ValueType  # 3
    """Logs all `DDL` statements, plus `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY FROM`."""
    ALL: _LogStatement.ValueType  # 4
    """Logs all statements."""

class LogStatement(_LogStatement, metaclass=_LogStatementEnumTypeWrapper): ...

LOG_STATEMENT_UNSPECIFIED: LogStatement.ValueType  # 0
NONE: LogStatement.ValueType  # 1
"""None statements are logged."""
DDL: LogStatement.ValueType  # 2
"""Logs all data definition commands like `CREATE`, `ALTER`, and `DROP`. Default value."""
MOD: LogStatement.ValueType  # 3
"""Logs all `DDL` statements, plus `INSERT`, `UPDATE`, `DELETE`, `TRUNCATE`, and `COPY FROM`."""
ALL: LogStatement.ValueType  # 4
"""Logs all statements."""
global___LogStatement = LogStatement

@typing.final
class Resources(google.protobuf.message.Message):
    """A list of computational resources allocated to a host."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_PRESET_ID_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    DISK_TYPE_ID_FIELD_NUMBER: builtins.int
    resource_preset_id: builtins.str
    """ID of the preset for computational resources allocated to a host.

    Available presets are listed in the [documentation](/docs/managed-greenplum/concepts/instance-types).
    """
    disk_size: builtins.int
    """Volume of the storage used by the host, in bytes."""
    disk_type_id: builtins.str
    """Type of the storage used by the host: `network-hdd`, `network-ssd` or `local-ssd`."""
    def __init__(
        self,
        *,
        resource_preset_id: builtins.str = ...,
        disk_size: builtins.int = ...,
        disk_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["disk_size", b"disk_size", "disk_type_id", b"disk_type_id", "resource_preset_id", b"resource_preset_id"]) -> None: ...

global___Resources = Resources

@typing.final
class ConnectionPoolerConfig(google.protobuf.message.Message):
    """Route server configuration."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PoolMode:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PoolModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ConnectionPoolerConfig._PoolMode.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        POOL_MODE_UNSPECIFIED: ConnectionPoolerConfig._PoolMode.ValueType  # 0
        SESSION: ConnectionPoolerConfig._PoolMode.ValueType  # 1
        """Assign server connection to a client until it disconnects. Default value."""
        TRANSACTION: ConnectionPoolerConfig._PoolMode.ValueType  # 2
        """Assign server connection to a client for a transaction processing."""

    class PoolMode(_PoolMode, metaclass=_PoolModeEnumTypeWrapper):
        """Route server pool mode."""

    POOL_MODE_UNSPECIFIED: ConnectionPoolerConfig.PoolMode.ValueType  # 0
    SESSION: ConnectionPoolerConfig.PoolMode.ValueType  # 1
    """Assign server connection to a client until it disconnects. Default value."""
    TRANSACTION: ConnectionPoolerConfig.PoolMode.ValueType  # 2
    """Assign server connection to a client for a transaction processing."""

    MODE_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    CLIENT_IDLE_TIMEOUT_FIELD_NUMBER: builtins.int
    mode: global___ConnectionPoolerConfig.PoolMode.ValueType
    """Route server pool mode."""
    @property
    def size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of servers in the server pool. Clients are placed in a wait queue when all servers are busy.

        Set to zero to disable the limit.
        """

    @property
    def client_idle_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Server pool idle timeout, in seconds.

        A server connection closes after being idle for the specified time.

        Set to zero to disable the limit.
        """

    def __init__(
        self,
        *,
        mode: global___ConnectionPoolerConfig.PoolMode.ValueType = ...,
        size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        client_idle_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["client_idle_timeout", b"client_idle_timeout", "size", b"size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["client_idle_timeout", b"client_idle_timeout", "mode", b"mode", "size", b"size"]) -> None: ...

global___ConnectionPoolerConfig = ConnectionPoolerConfig

@typing.final
class BackgroundActivityStartAt(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOURS_FIELD_NUMBER: builtins.int
    MINUTES_FIELD_NUMBER: builtins.int
    hours: builtins.int
    minutes: builtins.int
    def __init__(
        self,
        *,
        hours: builtins.int = ...,
        minutes: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hours", b"hours", "minutes", b"minutes"]) -> None: ...

global___BackgroundActivityStartAt = BackgroundActivityStartAt

@typing.final
class TableSizes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STARTS_FIELD_NUMBER: builtins.int
    @property
    def starts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BackgroundActivityStartAt]: ...
    def __init__(
        self,
        *,
        starts: collections.abc.Iterable[global___BackgroundActivityStartAt] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["starts", b"starts"]) -> None: ...

global___TableSizes = TableSizes

@typing.final
class AnalyzeAndVacuum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    ANALYZE_TIMEOUT_FIELD_NUMBER: builtins.int
    VACUUM_TIMEOUT_FIELD_NUMBER: builtins.int
    @property
    def start(self) -> global___BackgroundActivityStartAt: ...
    @property
    def analyze_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration of the `ANALYZE` operation, in seconds. The default value is `36000`. As soon as this period expires, the `ANALYZE` operation will be forced to terminate."""

    @property
    def vacuum_timeout(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration of the `VACUUM` operation, in seconds. The default value is `36000`. As soon as this period expires, the `VACUUM` operation will be forced to terminate."""

    def __init__(
        self,
        *,
        start: global___BackgroundActivityStartAt | None = ...,
        analyze_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        vacuum_timeout: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_timeout", b"analyze_timeout", "start", b"start", "vacuum_timeout", b"vacuum_timeout"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_timeout", b"analyze_timeout", "start", b"start", "vacuum_timeout", b"vacuum_timeout"]) -> None: ...

global___AnalyzeAndVacuum = AnalyzeAndVacuum

@typing.final
class BackgroundActivitiesConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TABLE_SIZES_FIELD_NUMBER: builtins.int
    ANALYZE_AND_VACUUM_FIELD_NUMBER: builtins.int
    QUERY_KILLER_SCRIPTS_FIELD_NUMBER: builtins.int
    @property
    def table_sizes(self) -> global___TableSizes:
        """Enables scripts that collects tables sizes to `*_sizes` tables in `mdb_toolkit` schema."""

    @property
    def analyze_and_vacuum(self) -> global___AnalyzeAndVacuum:
        """Configuration for `ANALYZE` and `VACUUM` operations."""

    @property
    def query_killer_scripts(self) -> global___QueryKillerScripts:
        """Configuration for long running queries killer."""

    def __init__(
        self,
        *,
        table_sizes: global___TableSizes | None = ...,
        analyze_and_vacuum: global___AnalyzeAndVacuum | None = ...,
        query_killer_scripts: global___QueryKillerScripts | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_and_vacuum", b"analyze_and_vacuum", "query_killer_scripts", b"query_killer_scripts", "table_sizes", b"table_sizes"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_and_vacuum", b"analyze_and_vacuum", "query_killer_scripts", b"query_killer_scripts", "table_sizes", b"table_sizes"]) -> None: ...

global___BackgroundActivitiesConfig = BackgroundActivitiesConfig

@typing.final
class QueryKiller(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    MAX_AGE_FIELD_NUMBER: builtins.int
    IGNORE_USERS_FIELD_NUMBER: builtins.int
    @property
    def enable(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    @property
    def max_age(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum duration for this type of queries (in seconds)."""

    @property
    def ignore_users(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Ignore these users when considering queries to terminate"""

    def __init__(
        self,
        *,
        enable: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_age: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ignore_users: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enable", b"enable", "max_age", b"max_age"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enable", b"enable", "ignore_users", b"ignore_users", "max_age", b"max_age"]) -> None: ...

global___QueryKiller = QueryKiller

@typing.final
class QueryKillerScripts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDLE_FIELD_NUMBER: builtins.int
    IDLE_IN_TRANSACTION_FIELD_NUMBER: builtins.int
    LONG_RUNNING_FIELD_NUMBER: builtins.int
    @property
    def idle(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries that are in `idle` state."""

    @property
    def idle_in_transaction(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries that are in `idle in transaction` state."""

    @property
    def long_running(self) -> global___QueryKiller:
        """Configuration of script that kills long running queries (in any state)."""

    def __init__(
        self,
        *,
        idle: global___QueryKiller | None = ...,
        idle_in_transaction: global___QueryKiller | None = ...,
        long_running: global___QueryKiller | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["idle", b"idle", "idle_in_transaction", b"idle_in_transaction", "long_running", b"long_running"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["idle", b"idle", "idle_in_transaction", b"idle_in_transaction", "long_running", b"long_running"]) -> None: ...

global___QueryKillerScripts = QueryKillerScripts

@typing.final
class MasterSubclusterConfig(google.protobuf.message.Message):
    """Configuration of the master subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to Greenplum® master subcluster hosts."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___MasterSubclusterConfig = MasterSubclusterConfig

@typing.final
class SegmentSubclusterConfig(google.protobuf.message.Message):
    """Configuration of the segment subcluster."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCES_FIELD_NUMBER: builtins.int
    @property
    def resources(self) -> global___Resources:
        """Computational resources allocated to Greenplum® segment subcluster hosts."""

    def __init__(
        self,
        *,
        resources: global___Resources | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["resources", b"resources"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["resources", b"resources"]) -> None: ...

global___SegmentSubclusterConfig = SegmentSubclusterConfig

@typing.final
class GreenplumConfig6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ADD_COLUMN_INHERITS_TABLE_SETTING_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#log_statement
    Default value is ddl
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment"""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specify the maximum size of WAL files that replication slots are allowed to retain in the pg_wal directory at checkpoint time.
        https://www.postgresql.org/docs/current/runtime-config-replication.html
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://www.postgresql.org/docs/9.6/runtime-config-resource.html
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://docs.greenplum.org/6-5/ref_guide/config_params/guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://greenplum.docs.pivotal.io/6-19/ref_guide/config_params/guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_add_column_inherits_table_setting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """https://docs.vmware.com/en/VMware-Tanzu-Greenplum/6/greenplum-database/GUID-ref_guide-config_params-guc-list.html#gp_add_column_inherits_table_setting"""

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_add_column_inherits_table_setting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "log_statement", b"log_statement", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> None: ...

global___GreenplumConfig6 = GreenplumConfig6

@typing.final
class GreenplumConfig6_17(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment."""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size of WAL files that replication slots are allowed to retain in the `pg_wal` directory at checkpoint time.

        More info in [PostgreSQL® documentation](https://www.postgresql.org/docs/current/runtime-config-replication.html).
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.

        The default value is 0 (no limit).

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_segment).
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum disk size that an individual query is allowed to use for creating temporary spill files at each segment.

        The default value is 0 (no limit).

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_query).
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of temporary spill files allowed per query at each segment.

        Spill files, also known as workfiles, are created when a query requires more memory than there is allocated.

        The current query is terminated if the limit is exceeded.

        Set to zero to disable the limit.

        Master session reloads if the parameter changes.

        Default value is 10000.

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_files_per_query).
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of transactions that can be in the `prepared` state simultaneously.

        More info in [PostgreSQL® documentation](https://www.postgresql.org/docs/9.6/runtime-config-resource.html).
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether the spill files are compressed or not.

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_compression).
        """

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size"]) -> None: ...

global___GreenplumConfig6_17 = GreenplumConfig6_17

@typing.final
class GreenplumConfig6_19(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Logged SQL statements.

    `PREPARE` and `EXPLAIN ANALYZE` statements are also logged if their contained command belongs to an appropriate type.

    More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_statement).
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment."""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum size of WAL files that replication slots are allowed to retain in the `pg_wal` directory at checkpoint time.

        More info in [PostgreSQL® documentation](https://www.postgresql.org/docs/current/runtime-config-replication.html).
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.

        The default value is 0 (no limit).

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_segment).
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum disk size that an individual query is allowed to use for creating temporary spill files at each segment.

        The default value is 0 (no limit).

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_query).
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of temporary spill files allowed per query at each segment.

        Spill files, also known as workfiles, are created when a query requires more memory than there is allocated.

        The current query is terminated if the limit is exceeded.

        Set to zero to disable the limit.

        Master session reloads if the parameter changes.

        Default value is 10000.

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_files_per_query).
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum number of transactions that can be in the `prepared` state simultaneously.

        More info in [PostgreSQL® documentation](https://www.postgresql.org/docs/9.6/runtime-config-resource.html).
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Whether the spill files are compressed or not.

        More info in [Greenplum® documentation](https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_compression).
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The maximum memory limit for a query, in bytes.

        Helps to avoid out-of-memory errors on a segment host during query processing as a result of setting `statement_mem` too high.

        Taking into account the configuration of a single segment host, calculate [max_statement_mem] as follows: `seghost_physical_memory` / `average_number_concurrent_queries`.

        When changing both [max_statement_mem] and `statement_mem`, [max_statement_mem] must be changed first, or listed first in the `postgresql.conf` file.

        Default value is 2097152000 (2000 MB).

        More info in [Greenplum® documentation](https://greenplum.docs.pivotal.io/6-19/ref_guide/config_params/guc-list.html#max_statement_mem).
        in bytes
        """

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "log_statement", b"log_statement", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> None: ...

global___GreenplumConfig6_19 = GreenplumConfig6_19

@typing.final
class GreenplumConfig6_21(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ADD_COLUMN_INHERITS_TABLE_SETTING_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_statement
    Default value is ddl
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment"""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specify the maximum size of WAL files that replication slots are allowed to retain in the pg_wal directory at checkpoint time.
        https://www.postgresql.org/docs/current/runtime-config-replication.html
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://www.postgresql.org/docs/9.6/runtime-config-resource.html
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://greenplum.docs.pivotal.io/6-19/ref_guide/config_params/guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_add_column_inherits_table_setting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """https://docs.vmware.com/en/VMware-Tanzu-Greenplum/6/greenplum-database/GUID-ref_guide-config_params-guc-list.html#gp_add_column_inherits_table_setting"""

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_add_column_inherits_table_setting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "log_statement", b"log_statement", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> None: ...

global___GreenplumConfig6_21 = GreenplumConfig6_21

@typing.final
class GreenplumConfig6_22(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CONNECTIONS_FIELD_NUMBER: builtins.int
    MAX_SLOT_WAL_KEEP_SIZE_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_SEGMENT_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_PER_QUERY_FIELD_NUMBER: builtins.int
    GP_WORKFILE_LIMIT_FILES_PER_QUERY_FIELD_NUMBER: builtins.int
    MAX_PREPARED_TRANSACTIONS_FIELD_NUMBER: builtins.int
    GP_WORKFILE_COMPRESSION_FIELD_NUMBER: builtins.int
    MAX_STATEMENT_MEM_FIELD_NUMBER: builtins.int
    LOG_STATEMENT_FIELD_NUMBER: builtins.int
    GP_ADD_COLUMN_INHERITS_TABLE_SETTING_FIELD_NUMBER: builtins.int
    log_statement: global___LogStatement.ValueType
    """Controls which SQL statements are logged. DDL logs all data definition commands like CREATE, ALTER, and DROP commands.
    MOD logs all DDL statements, plus INSERT, UPDATE, DELETE, TRUNCATE, and COPY FROM.
    PREPARE and EXPLAIN ANALYZE statements are also logged if their contained command is of an appropriate type.
    https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#log_statement
    Default value is ddl
    """
    @property
    def max_connections(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Maximum number of inbound connections on master segment"""

    @property
    def max_slot_wal_keep_size(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Specify the maximum size of WAL files that replication slots are allowed to retain in the pg_wal directory at checkpoint time.
        https://www.postgresql.org/docs/current/runtime-config-replication.html
        """

    @property
    def gp_workfile_limit_per_segment(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum total disk size that all running queries are allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_segment
        """

    @property
    def gp_workfile_limit_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum disk size an individual query is allowed to use for creating temporary spill files at each segment.
        The default value is 0, which means a limit is not enforced.
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_per_query
        """

    @property
    def gp_workfile_limit_files_per_query(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of temporary spill files (also known as workfiles) allowed per query per segment.
        Spill files are created when executing a query that requires more memory than it is allocated.
        The current query is terminated when the limit is exceeded.
        Set the value to 0 (zero) to allow an unlimited number of spill files. master session reload
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_limit_files_per_query
        Default value is 10000
        """

    @property
    def max_prepared_transactions(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum number of transactions that can be in the "prepared" state simultaneously
        https://www.postgresql.org/docs/9.6/runtime-config-resource.html
        """

    @property
    def gp_workfile_compression(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """Specifies whether the temporary files created, when a hash aggregation or hash join operation spills to disk, are compressed.
        https://docs.vmware.com/en/VMware-Greenplum/6/greenplum-database/ref_guide-config_params-guc-list.html#gp_workfile_compression
        """

    @property
    def max_statement_mem(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """Sets the maximum memory limit for a query. Helps avoid out-of-memory errors on a segment host during query processing as a result of setting statement_mem too high.
        Taking into account the configuration of a single segment host, calculate max_statement_mem as follows:
        (seghost_physical_memory) / (average_number_concurrent_queries)
        When changing both max_statement_mem and statement_mem, max_statement_mem must be changed first, or listed first in the postgresql.conf file.
        https://greenplum.docs.pivotal.io/6-19/ref_guide/config_params/guc-list.html#max_statement_mem
        Default value is 2097152000 (2000MB)
        in bytes
        """

    @property
    def gp_add_column_inherits_table_setting(self) -> google.protobuf.wrappers_pb2.BoolValue:
        """https://docs.vmware.com/en/VMware-Tanzu-Greenplum/6/greenplum-database/GUID-ref_guide-config_params-guc-list.html#gp_add_column_inherits_table_setting"""

    def __init__(
        self,
        *,
        max_connections: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_slot_wal_keep_size: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_segment: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_limit_files_per_query: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_prepared_transactions: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        gp_workfile_compression: google.protobuf.wrappers_pb2.BoolValue | None = ...,
        max_statement_mem: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        log_statement: global___LogStatement.ValueType = ...,
        gp_add_column_inherits_table_setting: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["gp_add_column_inherits_table_setting", b"gp_add_column_inherits_table_setting", "gp_workfile_compression", b"gp_workfile_compression", "gp_workfile_limit_files_per_query", b"gp_workfile_limit_files_per_query", "gp_workfile_limit_per_query", b"gp_workfile_limit_per_query", "gp_workfile_limit_per_segment", b"gp_workfile_limit_per_segment", "log_statement", b"log_statement", "max_connections", b"max_connections", "max_prepared_transactions", b"max_prepared_transactions", "max_slot_wal_keep_size", b"max_slot_wal_keep_size", "max_statement_mem", b"max_statement_mem"]) -> None: ...

global___GreenplumConfig6_22 = GreenplumConfig6_22

@typing.final
class GreenplumConfigSet6_17(google.protobuf.message.Message):
    """Configuration settings version 6.17"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6_17:
        """Effective settings for a Greenplum® cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___GreenplumConfig6_17:
        """User-defined settings for a Greenplum® cluster."""

    @property
    def default_config(self) -> global___GreenplumConfig6_17:
        """Default configuration for a Greenplum® cluster."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6_17 | None = ...,
        user_config: global___GreenplumConfig6_17 | None = ...,
        default_config: global___GreenplumConfig6_17 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6_17 = GreenplumConfigSet6_17

@typing.final
class GreenplumConfigSet6_19(google.protobuf.message.Message):
    """Configuration settings version 6.19"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6_19:
        """Effective settings for a Greenplum® cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___GreenplumConfig6_19:
        """User-defined settings for a Greenplum® cluster."""

    @property
    def default_config(self) -> global___GreenplumConfig6_19:
        """Default configuration for a Greenplum® cluster."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6_19 | None = ...,
        user_config: global___GreenplumConfig6_19 | None = ...,
        default_config: global___GreenplumConfig6_19 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6_19 = GreenplumConfigSet6_19

@typing.final
class GreenplumConfigSet6_21(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6_21:
        """Effective settings for a Greenplum®  cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___GreenplumConfig6_21:
        """User-defined settings for a Greenplum® cluster."""

    @property
    def default_config(self) -> global___GreenplumConfig6_21:
        """Default configuration for a Greenplum® cluster."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6_21 | None = ...,
        user_config: global___GreenplumConfig6_21 | None = ...,
        default_config: global___GreenplumConfig6_21 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6_21 = GreenplumConfigSet6_21

@typing.final
class GreenplumConfigSet6_22(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6_22:
        """Effective settings for a Greenplum®  cluster (a combination of settings defined in [user_config] and [default_config])."""

    @property
    def user_config(self) -> global___GreenplumConfig6_22:
        """User-defined settings for a Greenplum® cluster."""

    @property
    def default_config(self) -> global___GreenplumConfig6_22:
        """Default configuration for a Greenplum® cluster."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6_22 | None = ...,
        user_config: global___GreenplumConfig6_22 | None = ...,
        default_config: global___GreenplumConfig6_22 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6_22 = GreenplumConfigSet6_22

@typing.final
class GreenplumConfigSet6(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___GreenplumConfig6:
        """Effective settings for a Greenplum (a combination of settings defined
        in [user_config] and [default_config]).
        """

    @property
    def user_config(self) -> global___GreenplumConfig6:
        """User-defined settings for a Greenplum."""

    @property
    def default_config(self) -> global___GreenplumConfig6:
        """Default configuration for a Greenplum."""

    def __init__(
        self,
        *,
        effective_config: global___GreenplumConfig6 | None = ...,
        user_config: global___GreenplumConfig6 | None = ...,
        default_config: global___GreenplumConfig6 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___GreenplumConfigSet6 = GreenplumConfigSet6

@typing.final
class ConnectionPoolerConfigSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EFFECTIVE_CONFIG_FIELD_NUMBER: builtins.int
    USER_CONFIG_FIELD_NUMBER: builtins.int
    DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def effective_config(self) -> global___ConnectionPoolerConfig:
        """Effective settings for an Odyssey® pooler (a combination of settings defined in [ConnectionPoolerConfigSet.user_config] and [ConnectionPoolerConfigSet.default_config])."""

    @property
    def user_config(self) -> global___ConnectionPoolerConfig:
        """User-defined settings for an Odyssey® pooler."""

    @property
    def default_config(self) -> global___ConnectionPoolerConfig:
        """Default configuration for an Odyssey® pooler."""

    def __init__(
        self,
        *,
        effective_config: global___ConnectionPoolerConfig | None = ...,
        user_config: global___ConnectionPoolerConfig | None = ...,
        default_config: global___ConnectionPoolerConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["default_config", b"default_config", "effective_config", b"effective_config", "user_config", b"user_config"]) -> None: ...

global___ConnectionPoolerConfigSet = ConnectionPoolerConfigSet



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _PricingVersionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PricingVersionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PricingVersionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PRICING_VERSION_TYPE_UNSPECIFIED: _PricingVersionType.ValueType  # 0
    STREET_PRICE: _PricingVersionType.ValueType  # 1
    """Regular price."""
    CONTRACT_PRICE: _PricingVersionType.ValueType  # 2
    """Price is overridden by a contract. Defined in the scope of a billing account."""

class PricingVersionType(_PricingVersionType, metaclass=_PricingVersionTypeEnumTypeWrapper):
    """Type of the pricing version."""

PRICING_VERSION_TYPE_UNSPECIFIED: PricingVersionType.ValueType  # 0
STREET_PRICE: PricingVersionType.ValueType  # 1
"""Regular price."""
CONTRACT_PRICE: PricingVersionType.ValueType  # 2
"""Price is overridden by a contract. Defined in the scope of a billing account."""
global___PricingVersionType = PricingVersionType

@typing.final
class Sku(google.protobuf.message.Message):
    """A Stock keeping unit resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SERVICE_ID_FIELD_NUMBER: builtins.int
    PRICING_UNIT_FIELD_NUMBER: builtins.int
    PRICING_VERSIONS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the SKU."""
    name: builtins.str
    """Name of the SKU."""
    description: builtins.str
    """Description of the sku."""
    service_id: builtins.str
    """ID of the service that sku belongs to."""
    pricing_unit: builtins.str
    """Pricing unit of the SKU, e.g. `core*hour`, `gbyte*hour`."""
    @property
    def pricing_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PricingVersion]:
        """List of pricing versions."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        service_id: builtins.str = ...,
        pricing_unit: builtins.str = ...,
        pricing_versions: collections.abc.Iterable[global___PricingVersion] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "id", b"id", "name", b"name", "pricing_unit", b"pricing_unit", "pricing_versions", b"pricing_versions", "service_id", b"service_id"]) -> None: ...

global___Sku = Sku

@typing.final
class PricingVersion(google.protobuf.message.Message):
    """Pricing version of the SKU.
    Defines current and past prices for the sku.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    EFFECTIVE_TIME_FIELD_NUMBER: builtins.int
    PRICING_EXPRESSIONS_FIELD_NUMBER: builtins.int
    type: global___PricingVersionType.ValueType
    """Type of the pricing version."""
    @property
    def effective_time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp pricing version is active since inclusive.
        The pricing version is active until next pricing version effective time exclusive.
        """

    @property
    def pricing_expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PricingExpression]:
        """List of pricing expressions."""

    def __init__(
        self,
        *,
        type: global___PricingVersionType.ValueType = ...,
        effective_time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        pricing_expressions: collections.abc.Iterable[global___PricingExpression] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["effective_time", b"effective_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["effective_time", b"effective_time", "pricing_expressions", b"pricing_expressions", "type", b"type"]) -> None: ...

global___PricingVersion = PricingVersion

@typing.final
class PricingExpression(google.protobuf.message.Message):
    """Pricing expression of the pricing version.
    Defines price for the sku.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RATES_FIELD_NUMBER: builtins.int
    @property
    def rates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Rate]:
        """List of rates."""

    def __init__(
        self,
        *,
        rates: collections.abc.Iterable[global___Rate] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rates", b"rates"]) -> None: ...

global___PricingExpression = PricingExpression

@typing.final
class Rate(google.protobuf.message.Message):
    """Rate of the pricing expression.
    Define unit price for pricing quantity interval.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_PRICING_QUANTITY_FIELD_NUMBER: builtins.int
    UNIT_PRICE_FIELD_NUMBER: builtins.int
    CURRENCY_FIELD_NUMBER: builtins.int
    start_pricing_quantity: builtins.str
    """Start of the pricing quantity interval. The end of the interval is the start pricing quantity of the next rate."""
    unit_price: builtins.str
    """Unit price for the pricing quantity interval."""
    currency: builtins.str
    """Currency of the unit price.
    Can be one of the following:
    * `RUB`
    * `USD`
    * `KZT`
    """
    def __init__(
        self,
        *,
        start_pricing_quantity: builtins.str = ...,
        unit_price: builtins.str = ...,
        currency: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["currency", b"currency", "start_pricing_quantity", b"start_pricing_quantity", "unit_price", b"unit_price"]) -> None: ...

global___Rate = Rate



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.datasphere.v1.project_data_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProjectDataServiceStub:
    """A set of methods for managing data of the Project resource."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    UploadFile: grpc.StreamUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileRequest,
        yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileResponse,
    ]
    """Uploads a file to the specified project."""

    DownloadFile: grpc.UnaryStreamMultiCallable[
        yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileRequest,
        yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileResponse,
    ]
    """Downloads the specified file from the specified project."""

class ProjectDataServiceAsyncStub:
    """A set of methods for managing data of the Project resource."""

    UploadFile: grpc.aio.StreamUnaryMultiCallable[
        yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileRequest,
        yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileResponse,
    ]
    """Uploads a file to the specified project."""

    DownloadFile: grpc.aio.UnaryStreamMultiCallable[
        yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileRequest,
        yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileResponse,
    ]
    """Downloads the specified file from the specified project."""

class ProjectDataServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing data of the Project resource."""

    @abc.abstractmethod
    def UploadFile(
        self,
        request_iterator: _MaybeAsyncIterator[yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileRequest],
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v1.project_data_service_pb2.UploadFileResponse]]:
        """Uploads a file to the specified project."""

    @abc.abstractmethod
    def DownloadFile(
        self,
        request: yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileRequest,
        context: _ServicerContext,
    ) -> typing.Union[collections.abc.Iterator[yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileResponse], collections.abc.AsyncIterator[yandex.cloud.datasphere.v1.project_data_service_pb2.DownloadFileResponse]]:
        """Downloads the specified file from the specified project."""

def add_ProjectDataServiceServicer_to_server(servicer: ProjectDataServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.cic.v1.peering_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PublicConnection(google.protobuf.message.Message):
    """A PublicConnection resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _CloudServiceType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _CloudServiceTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[PublicConnection._CloudServiceType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CLOUD_SERVICE_TYPE_UNSPECIFIED: PublicConnection._CloudServiceType.ValueType  # 0
        CLOUD_SERVICE_YANDEX: PublicConnection._CloudServiceType.ValueType  # 1
        CLOUD_SERVICE_ALL_PUBLIC: PublicConnection._CloudServiceType.ValueType  # 2
        CLOUD_SERVICE_S3: PublicConnection._CloudServiceType.ValueType  # 3
        CLOUD_SERVICE_ML: PublicConnection._CloudServiceType.ValueType  # 4
        CLOUD_SERVICE_APIGW: PublicConnection._CloudServiceType.ValueType  # 5
        CLOUD_SERVICE_CONTAINER_REGISTRY: PublicConnection._CloudServiceType.ValueType  # 6
        CLOUD_SERVICE_CONSOLE: PublicConnection._CloudServiceType.ValueType  # 7
        CLOUD_SERVICE_MONITORING: PublicConnection._CloudServiceType.ValueType  # 8
        CLOUD_SERVICE_YANDEX_GPT: PublicConnection._CloudServiceType.ValueType  # 9
        CLOUD_SERVICES_ALL_API_ENDPOINT: PublicConnection._CloudServiceType.ValueType  # 10
        CLOUD_SERVICE_YMQ: PublicConnection._CloudServiceType.ValueType  # 11

    class CloudServiceType(_CloudServiceType, metaclass=_CloudServiceTypeEnumTypeWrapper): ...
    CLOUD_SERVICE_TYPE_UNSPECIFIED: PublicConnection.CloudServiceType.ValueType  # 0
    CLOUD_SERVICE_YANDEX: PublicConnection.CloudServiceType.ValueType  # 1
    CLOUD_SERVICE_ALL_PUBLIC: PublicConnection.CloudServiceType.ValueType  # 2
    CLOUD_SERVICE_S3: PublicConnection.CloudServiceType.ValueType  # 3
    CLOUD_SERVICE_ML: PublicConnection.CloudServiceType.ValueType  # 4
    CLOUD_SERVICE_APIGW: PublicConnection.CloudServiceType.ValueType  # 5
    CLOUD_SERVICE_CONTAINER_REGISTRY: PublicConnection.CloudServiceType.ValueType  # 6
    CLOUD_SERVICE_CONSOLE: PublicConnection.CloudServiceType.ValueType  # 7
    CLOUD_SERVICE_MONITORING: PublicConnection.CloudServiceType.ValueType  # 8
    CLOUD_SERVICE_YANDEX_GPT: PublicConnection.CloudServiceType.ValueType  # 9
    CLOUD_SERVICES_ALL_API_ENDPOINT: PublicConnection.CloudServiceType.ValueType  # 10
    CLOUD_SERVICE_YMQ: PublicConnection.CloudServiceType.ValueType  # 11

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    REGION_ID_FIELD_NUMBER: builtins.int
    TRUNK_CONNECTION_ID_FIELD_NUMBER: builtins.int
    VLAN_ID_FIELD_NUMBER: builtins.int
    IPV4_PEERING_FIELD_NUMBER: builtins.int
    IPV4_ALLOWED_SERVICE_TYPES_FIELD_NUMBER: builtins.int
    IPV4_PEER_ANNOUNCED_PREFIXES_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the publicConnection."""
    name: builtins.str
    """Name of the publicConnection.
    The name must be unique within the folder.
    Value must match the regular expression ``\\|[a-zA-Z]([-_a-zA-Z0-9]{0,61}[a-zA-Z0-9])?``.
    """
    description: builtins.str
    """Optional description of the publicConnection. 0-256 characters long."""
    folder_id: builtins.str
    """ID of the folder that the publicConnection belongs to."""
    region_id: builtins.str
    """ID of the region that the publicConnection belongs to."""
    trunk_connection_id: builtins.str
    """ID of the trunk_connection that the publicConnection belongs to."""
    @property
    def vlan_id(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """VLAN_ID that the privateConnection uses in multiplexing.
        Not used in connections over partners-II
        Value range: [1, 4095]
        """

    @property
    def ipv4_peering(self) -> yandex.cloud.cic.v1.peering_pb2.Peering:
        """IPv4 peering config of connection"""

    @property
    def ipv4_allowed_service_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___PublicConnection.CloudServiceType.ValueType]:
        """Cloud services that the publicConnection connects to."""

    @property
    def ipv4_peer_announced_prefixes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """IPv4 Peer Announced Prefixes
        It's an list of ip with format ipPrefix/length where address part of ipPrefix is 0
        """

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels, `key:value` pairs.
        No more than 64 per resource.
        The maximum string length in characters for each value is 63.
        Each value must match the regular expression `[-_0-9a-z]*`.
        The string length in characters for each key must be 1-63.
        Each key must match the regular expression `[a-z][-_0-9a-z]*`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        folder_id: builtins.str = ...,
        region_id: builtins.str = ...,
        trunk_connection_id: builtins.str = ...,
        vlan_id: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        ipv4_peering: yandex.cloud.cic.v1.peering_pb2.Peering | None = ...,
        ipv4_allowed_service_types: collections.abc.Iterable[global___PublicConnection.CloudServiceType.ValueType] | None = ...,
        ipv4_peer_announced_prefixes: collections.abc.Iterable[builtins.str] | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["ipv4_peering", b"ipv4_peering", "vlan_id", b"vlan_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "id", b"id", "ipv4_allowed_service_types", b"ipv4_allowed_service_types", "ipv4_peer_announced_prefixes", b"ipv4_peer_announced_prefixes", "ipv4_peering", b"ipv4_peering", "labels", b"labels", "name", b"name", "region_id", b"region_id", "trunk_connection_id", b"trunk_connection_id", "vlan_id", b"vlan_id"]) -> None: ...

global___PublicConnection = PublicConnection



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/marketplace/v1/helm_release.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/k8s/marketplace/v1/helm_release.proto\x12\x1fyandex.cloud.k8s.marketplace.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\x03\n\x0bHelmRelease\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x10\n\x08\x61pp_name\x18\x03 \x01(\t\x12\x15\n\rapp_namespace\x18\x04 \x01(\t\x12\x12\n\nproduct_id\x18\x05 \x01(\t\x12\x14\n\x0cproduct_name\x18\x06 \x01(\t\x12\x17\n\x0fproduct_version\x18\n \x01(\t\x12\x43\n\x06status\x18\x07 \x01(\x0e\x32\x33.yandex.cloud.k8s.marketplace.v1.HelmRelease.Status\x12.\n\ncreated_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xba\x01\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0c\n\x08\x44\x45PLOYED\x10\x02\x12\x0f\n\x0bUNINSTALLED\x10\x03\x12\x0e\n\nSUPERSEDED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\x10\n\x0cUNINSTALLING\x10\x06\x12\x13\n\x0fPENDING_INSTALL\x10\x07\x12\x13\n\x0fPENDING_UPGRADE\x10\x08\x12\x14\n\x10PENDING_ROLLBACK\x10\tJ\x04\x08\t\x10\nBz\n#yandex.cloud.api.k8s.marketplace.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/k8s/marketplace/v1;k8s_marketplaceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.marketplace.v1.helm_release_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.k8s.marketplace.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/k8s/marketplace/v1;k8s_marketplace'
  _globals['_HELMRELEASE']._serialized_start=121
  _globals['_HELMRELEASE']._serialized_end=586
  _globals['_HELMRELEASE_STATUS']._serialized_start=394
  _globals['_HELMRELEASE_STATUS']._serialized_end=580
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.k8s.v1.cluster_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListVersionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___ListVersionsRequest = ListVersionsRequest

@typing.final
class ListVersionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_VERSIONS_FIELD_NUMBER: builtins.int
    @property
    def available_versions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AvailableVersions]:
        """Versions available in the specified release channel."""

    def __init__(
        self,
        *,
        available_versions: collections.abc.Iterable[global___AvailableVersions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["available_versions", b"available_versions"]) -> None: ...

global___ListVersionsResponse = ListVersionsResponse

@typing.final
class AvailableVersions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RELEASE_CHANNEL_FIELD_NUMBER: builtins.int
    VERSIONS_FIELD_NUMBER: builtins.int
    release_channel: yandex.cloud.k8s.v1.cluster_pb2.ReleaseChannel.ValueType
    """Release channel: `RAPID`, `REGULAR` or `STABLE`. For more details see [documentation](/docs/managed-kubernetes/concepts/release-channels-and-updates)."""
    @property
    def versions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Version of Kubernetes components."""

    def __init__(
        self,
        *,
        release_channel: yandex.cloud.k8s.v1.cluster_pb2.ReleaseChannel.ValueType = ...,
        versions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["release_channel", b"release_channel", "versions", b"versions"]) -> None: ...

global___AvailableVersions = AvailableVersions



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint/serializers.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7yandex/cloud/datatransfer/v1/endpoint/serializers.proto\x12%yandex.cloud.datatransfer.v1.endpoint\"\x10\n\x0eSerializerAuto\"\x10\n\x0eSerializerJSON\"9\n\x1b\x44\x65\x62\x65ziumSerializerParameter\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"w\n\x12SerializerDebezium\x12\x61\n\x15serializer_parameters\x18\x01 \x03(\x0b\x32\x42.yandex.cloud.datatransfer.v1.endpoint.DebeziumSerializerParameter\"\x98\x02\n\nSerializer\x12P\n\x0fserializer_auto\x18\x01 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.SerializerAutoH\x00\x12P\n\x0fserializer_json\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.SerializerJSONH\x00\x12X\n\x13serializer_debezium\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.datatransfer.v1.endpoint.SerializerDebeziumH\x00\x42\x0c\n\nserializerB\xa7\x01\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\xaa\x02%Yandex.Cloud.Datatransfer.V1.EndPointb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint.serializers_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.datatransfer.v1.endpointZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1/endpoint;endpoint\252\002%Yandex.Cloud.Datatransfer.V1.EndPoint'
  _globals['_SERIALIZERAUTO']._serialized_start=98
  _globals['_SERIALIZERAUTO']._serialized_end=114
  _globals['_SERIALIZERJSON']._serialized_start=116
  _globals['_SERIALIZERJSON']._serialized_end=132
  _globals['_DEBEZIUMSERIALIZERPARAMETER']._serialized_start=134
  _globals['_DEBEZIUMSERIALIZERPARAMETER']._serialized_end=191
  _globals['_SERIALIZERDEBEZIUM']._serialized_start=193
  _globals['_SERIALIZERDEBEZIUM']._serialized_end=312
  _globals['_SERIALIZER']._serialized_start=315
  _globals['_SERIALIZER']._serialized_end=595
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.mdb.sqlserver.v1.database_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster the database belongs to.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the SQL Server database to return.

    To get the name of the database use a [DatabaseService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___GetDatabaseRequest = GetDatabaseRequest

@typing.final
class ListDatabasesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster to list databases in.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return.

    If the number of available results is larger than [page_size], the service returns a [ListDatabasesResponse.next_page_token] that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the [ListDatabasesResponse.next_page_token] returned by the previous list request."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListDatabasesRequest = ListDatabasesRequest

@typing.final
class ListDatabasesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATABASES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token that allows you to get the next page of results for list requests.

    If the number of results is larger than [ListDatabasesRequest.page_size], use the [next_page_token] as the value for the [ListDatabasesRequest.page_token] parameter in the next list request.

    Each subsequent list request has its own [next_page_token] to continue paging through the results.
    """
    @property
    def databases(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.sqlserver.v1.database_pb2.Database]:
        """List of SQL Server databases."""

    def __init__(
        self,
        *,
        databases: collections.abc.Iterable[yandex.cloud.mdb.sqlserver.v1.database_pb2.Database] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["databases", b"databases", "next_page_token", b"next_page_token"]) -> None: ...

global___ListDatabasesResponse = ListDatabasesResponse

@typing.final
class CreateDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster to create a database in.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    @property
    def database_spec(self) -> yandex.cloud.mdb.sqlserver.v1.database_pb2.DatabaseSpec:
        """Configuration of the database to create."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_spec: yandex.cloud.mdb.sqlserver.v1.database_pb2.DatabaseSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["database_spec", b"database_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_spec", b"database_spec"]) -> None: ...

global___CreateDatabaseRequest = CreateDatabaseRequest

@typing.final
class CreateDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster where the database is being created."""
    database_name: builtins.str
    """Name of the SQL Server database being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___CreateDatabaseMetadata = CreateDatabaseMetadata

@typing.final
class DeleteDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster to delete a database in.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the database to delete.

    To get the name of the database, use a [DatabaseService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseRequest = DeleteDatabaseRequest

@typing.final
class DeleteDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster where the database is being deleted."""
    database_name: builtins.str
    """Name of the SQL Server database being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name"]) -> None: ...

global___DeleteDatabaseMetadata = DeleteDatabaseMetadata

@typing.final
class RestoreDatabaseRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    FROM_DATABASE_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster to restore a database in.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the SQL Server database that is being restored."""
    from_database: builtins.str
    """Name of the database which backup is used to restore the database."""
    backup_id: builtins.str
    """ID of a backup to be used."""
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp which is used for Point-in-Time recovery."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        from_database: builtins.str = ...,
        backup_id: builtins.str = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["time", b"time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "cluster_id", b"cluster_id", "database_name", b"database_name", "from_database", b"from_database", "time", b"time"]) -> None: ...

global___RestoreDatabaseRequest = RestoreDatabaseRequest

@typing.final
class RestoreDatabaseMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    FROM_DATABASE_FIELD_NUMBER: builtins.int
    BACKUP_ID_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster where a database is being created."""
    database_name: builtins.str
    """Name of an SQL Server database that is being created."""
    from_database: builtins.str
    """Name of the database which backup is used to restore the database."""
    backup_id: builtins.str
    """ID of a backup to be used."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        from_database: builtins.str = ...,
        backup_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["backup_id", b"backup_id", "cluster_id", b"cluster_id", "database_name", b"database_name", "from_database", b"from_database"]) -> None: ...

global___RestoreDatabaseMetadata = RestoreDatabaseMetadata

@typing.final
class ImportDatabaseBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_PATH_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster to import a database in.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the SQL Server database that is being imported."""
    s3_bucket: builtins.str
    """Name of object storage bucket to import backups from."""
    s3_path: builtins.str
    """Path in object storage bucket to import backups from."""
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of .bak files in bucket containing database backup."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_path: builtins.str = ...,
        files: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "files", b"files", "s3_bucket", b"s3_bucket", "s3_path", b"s3_path"]) -> None: ...

global___ImportDatabaseBackupRequest = ImportDatabaseBackupRequest

@typing.final
class ImportDatabaseBackupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_PATH_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster where a database is being imported."""
    database_name: builtins.str
    """Name of the SQL Server database that is being imported."""
    s3_bucket: builtins.str
    """Name of object storage bucket to import backups from."""
    s3_path: builtins.str
    """Path in object storage bucket to import backups from."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "s3_bucket", b"s3_bucket", "s3_path", b"s3_path"]) -> None: ...

global___ImportDatabaseBackupMetadata = ImportDatabaseBackupMetadata

@typing.final
class ExportDatabaseBackupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_PATH_FIELD_NUMBER: builtins.int
    PREFIX_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster to export a database from.

    To get the cluster ID, use a [ClusterService.List] request.
    """
    database_name: builtins.str
    """Name of the SQL Server database that is being exported."""
    s3_bucket: builtins.str
    """Name of object storage bucket to export backups to."""
    s3_path: builtins.str
    """Path in object storage bucket to export backups to."""
    prefix: builtins.str
    """Prefix for .bak files to export."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_path: builtins.str = ...,
        prefix: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "prefix", b"prefix", "s3_bucket", b"s3_bucket", "s3_path", b"s3_path"]) -> None: ...

global___ExportDatabaseBackupRequest = ExportDatabaseBackupRequest

@typing.final
class ExportDatabaseBackupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_PATH_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the SQL Server cluster where a database is being exported."""
    database_name: builtins.str
    """Name of the SQL Server database that is being exported."""
    s3_bucket: builtins.str
    """Name of object storage bucket to export backups to."""
    s3_path: builtins.str
    """Path in object storage bucket to export backups to."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        database_name: builtins.str = ...,
        s3_bucket: builtins.str = ...,
        s3_path: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "s3_bucket", b"s3_bucket", "s3_path", b"s3_path"]) -> None: ...

global___ExportDatabaseBackupMetadata = ExportDatabaseBackupMetadata
